@@ -16,6 +16,16 @@ class BaseSubModel(pybamm.BaseModel):
     ----------
     param: parameter class
         The model parameter symbols
+    domain : str
+        The domain of the model either 'Negative' or 'Positive'
+    name: str
+        A string giving the name of the submodel
+    external: bool, optional
+        Whether the variables defined by the submodel will be provided externally
+        by the users. Default is 'False'.
+    options: dict
+        A dictionary of options to be passed to the model.
+        See :class:`pybamm.BaseBatteryModel`
 
     Attributes
     ----------
@@ -47,7 +57,7 @@ class BaseSubModel(pybamm.BaseModel):
     """
 
     def __init__(
-        self, param, domain=None, name="Unnamed submodel", external=False,
+        self, param, domain=None, name="Unnamed submodel", external=False, options=None
     ):
         super().__init__(name)
         self.param = param
@@ -57,6 +67,11 @@ class BaseSubModel(pybamm.BaseModel):
         self.name = name
 
         self.external = external
+        self.options = pybamm.BatteryModelOptions(options or {})
+
+        # Save whether the submodel is a half-cell submodel
+        we = self.options["working electrode"]
+        self.half_cell = we != "both"
 
     @property
     def domain(self):
