@@ -123,8 +123,8 @@ class BaseModel(BaseElectrolyteConductivity):
 
     def _get_conductivities(self, variables):
         param = self.param
-        tor_e = variables[self.domain + " electrolyte tortuosity"]
-        tor_s = variables[self.domain + " electrode tortuosity"]
+        tor_e = variables[self.domain + " electrolyte transport efficiency"]
+        tor_s = variables[self.domain + " electrode transport efficiency"]
         c_e = variables[self.domain + " electrolyte concentration"]
         T = variables[self.domain + " electrode temperature"]
         if self.domain == "Negative":
