@@ -25,9 +25,8 @@ class NoOxygen(BaseModel):
         c_ox_n = pybamm.FullBroadcast(0, ["negative electrode"], "current collector")
         c_ox_s = pybamm.FullBroadcast(0, ["separator"], "current collector")
         c_ox_p = pybamm.FullBroadcast(0, ["positive electrode"], "current collector")
-        c_ox = pybamm.Concatenation(c_ox_n, c_ox_s, c_ox_p)
 
-        variables = self._get_standard_concentration_variables(c_ox)
+        variables = self._get_standard_concentration_variables(c_ox_n, c_ox_s, c_ox_p)
 
         N_e = pybamm.FullBroadcastToEdges(
             0,
