@@ -36,6 +36,8 @@ class ScikitsDaeSolver(pybamm.BaseSolver):
         specified by 'root_method' (e.g. "lm", "hybr", ...)
     root_tol : float, optional
         The tolerance for the initial-condition solver (default is 1e-6).
+    extrap_tol : float, optional
+        The tolerance to assert whether extrapolation occurs or not (default is 0).
     extra_options : dict, optional
         Any options to pass to the solver.
         Please consult `scikits.odes documentation
@@ -52,22 +54,24 @@ class ScikitsDaeSolver(pybamm.BaseSolver):
         atol=1e-6,
         root_method="casadi",
         root_tol=1e-6,
+        extrap_tol=0,
         extra_options=None,
-        max_steps="deprecated",
     ):
         if scikits_odes_spec is None:
             raise ImportError("scikits.odes is not installed")
 
-        super().__init__(method, rtol, atol, root_method, root_tol, max_steps)
+        super().__init__(
+            method, rtol, atol, root_method, root_tol, extrap_tol
+        )
         self.name = "Scikits DAE solver ({})".format(method)
 
         self.extra_options = extra_options or {}
 
-        pybamm.citations.register("scikits-odes")
-        pybamm.citations.register("hindmarsh2000pvode")
-        pybamm.citations.register("hindmarsh2005sundials")
+        pybamm.citations.register("Malengier2018")
+        pybamm.citations.register("Hindmarsh2000")
+        pybamm.citations.register("Hindmarsh2005")
 
-    def _integrate(self, model, t_eval, inputs=None):
+    def _integrate(self, model, t_eval, inputs_dict=None):
         """
         Solve a model defined by dydt with initial conditions y0.
 
@@ -77,24 +81,41 @@ class ScikitsDaeSolver(pybamm.BaseSolver):
             The model whose solution to calculate.
         t_eval : numeric type
             The times at which to compute the solution
-        inputs : dict, optional
+        inputs_dict : dict, optional
             Any input parameters to pass to the model when solving
 
         """
+        inputs_dict = inputs_dict or {}
         if model.convert_to_format == "casadi":
-            inputs = casadi.vertcat(*[x for x in inputs.values()])
+            inputs = casadi.vertcat(*[x for x in inputs_dict.values()])
+        else:
+            inputs = inputs_dict
 
         y0 = model.y0
         if isinstance(y0, casadi.DM):
-            y0 = y0.full().flatten()
+            y0 = y0.full()
+        y0 = y0.flatten()
 
-        residuals = model.residuals_eval
+        rhs_algebraic_eval = model.rhs_algebraic_eval
         events = model.terminate_events_eval
-        jacobian = model.jacobian_eval
-        mass_matrix = model.mass_matrix.entries
+        jacobian = model.jac_rhs_algebraic_eval
+        if model.convert_to_format == "jax":
+            mass_matrix = model.mass_matrix.entries.toarray()
+        else:
+            mass_matrix = model.mass_matrix.entries
 
-        def eqsres(t, y, ydot, return_residuals):
-            return_residuals[:] = residuals(t, y, ydot, inputs)
+        if model.convert_to_format == "casadi":
+            def eqsres(t, y, ydot, return_residuals):
+                return_residuals[:] = (
+                    rhs_algebraic_eval(t, y, inputs).full().flatten()
+                    - mass_matrix @ ydot
+                )
+        else:
+            def eqsres(t, y, ydot, return_residuals):
+                return_residuals[:] = (
+                    rhs_algebraic_eval(t, y, inputs).flatten()
+                    - mass_matrix @ ydot
+                )
 
         def rootfn(t, y, ydot, return_root):
             return_root[:] = [event(t, y, inputs) for event in events]
@@ -109,13 +130,10 @@ class ScikitsDaeSolver(pybamm.BaseSolver):
         if jacobian:
             jac_y0_t0 = jacobian(t_eval[0], y0, inputs)
             if sparse.issparse(jac_y0_t0):
-
                 def jacfn(t, y, ydot, residuals, cj, J):
                     jac_eval = jacobian(t, y, inputs) - cj * mass_matrix
                     J[:][:] = jac_eval.toarray()
-
             else:
-
                 def jacfn(t, y, ydot, residuals, cj, J):
                     jac_eval = jacobian(t, y, inputs) - cj * mass_matrix
                     J[:][:] = jac_eval
@@ -130,7 +148,9 @@ class ScikitsDaeSolver(pybamm.BaseSolver):
 
         # set up and solve
         dae_solver = scikits_odes.dae(self.method, eqsres, **extra_options)
+        timer = pybamm.Timer()
         sol = dae_solver.solve(t_eval, y0, ydot0)
+        integration_time = timer.time()
 
         # return solution, we need to tranpose y to match scipy's interface
         if sol.flag in [0, 2]:
@@ -144,12 +164,16 @@ class ScikitsDaeSolver(pybamm.BaseSolver):
                 t_root = None
             else:
                 t_root = sol.roots.t
-            return pybamm.Solution(
+            sol = pybamm.Solution(
                 sol.values.t,
                 np.transpose(sol.values.y),
+                model,
+                inputs_dict,
                 t_root,
                 np.transpose(sol.roots.y),
                 termination,
             )
+            sol.integration_time = integration_time
+            return sol
         else:
             raise pybamm.SolverError(sol.message)
